"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const opentracing_1 = require("opentracing");
const base_1 = require("./base");
const util_1 = require("./util");
class Worker extends base_1.default {
    /**
     * Metodo para procesar los mensajes entrantes
     * @param data Datos de la peticion
     */
    message(data, Method, params = []) {
        return new Promise((rr, ff) => {
            // Ejecutar la funcion
            try {
                const paraInject = [];
                const log = {
                    event: 'input',
                };
                const original = data.data
                    ? data.data
                    : data.metadata.data_inicial;
                params.forEach((value) => {
                    if (value === 'uuid') {
                        paraInject.push(data.metadata.uuid);
                    }
                    else if (value === 'filters') {
                        paraInject.push(this.transformFilters(data.metadata.filters));
                        log.uuid = data.metadata.uuid;
                    }
                    else if (value === 'authorizacion') {
                        paraInject.push(data.headers.Authorizacion);
                        log.authorizacion = data.headers.Authorizacion;
                    }
                    else if (value === 'data') {
                        paraInject.push(original);
                        log.data = original;
                    }
                    else if (value === 'response') {
                        if (data.response &&
                            data.response.data &&
                            data.response.data.response) {
                            paraInject.push(data.response.data.response);
                            log.response = data.response.data.response;
                        }
                        else {
                            paraInject.push(original);
                            log.response = original;
                        }
                    }
                    else if (value === 'parentSpan') {
                        paraInject.push(this.span);
                    }
                });
                this.span.log(log);
                const resp = Method.apply({}, paraInject);
                // Validar si la respuesta es una promesa y esperar a resolverla
                if (util_1.default.isPromise(resp)) {
                    // Esperar que finalice
                    resp.then((response) => {
                        // Regresar el contenido
                        rr(this.formatResponse(data, response, 0));
                    }).catch((error) => {
                        this.span.setTag(opentracing_1.Tags.ERROR, true);
                        this.span.log({
                            'error.message': error.message,
                            'error.object': error,
                            'error.stack': error.stack,
                            // tslint:disable-next-line: object-literal-key-quotes
                            event: 'error',
                        });
                        // Indicar que fue error
                        ff(this.formatResponse(data, null, error.code));
                    });
                }
                else {
                    const r = this.formatResponse(data, resp, 0);
                    // Regresar la respuesta
                    rr(r);
                }
            }
            catch (error) {
                this.span.setTag(opentracing_1.Tags.ERROR, true);
                this.span.log({
                    'error.message': error.message,
                    'error.object': error,
                    'error.stack': error.stack,
                    // tslint:disable-next-line: object-literal-key-quotes
                    event: 'error',
                });
                // Regresar el error
                ff(this.formatResponse(data, null, error.code));
            }
        });
    }
}
exports.default = Worker;
