"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("util");
/**
 * Clase base para los Worker y Fork
 */
class Base {
    /**
     * Contructor de la clase
     * @param conf Configuracion del servicio
     */
    constructor(conf, topic, span) {
        /**
         * Topico del servicio
         * @protected
         */
        this.Topic = '';
        this.config = conf;
        this.Topic = topic;
        this.span = span;
    }
    /**
     * Metodo que hace rel registro de Forks
     * para su utilizacion sobre los servicios.
     * @param conf Configuracion para el evento
     */
    forksConfig(conf) {
        return;
    }
    transformFilters(filters) {
        if (util_1.isNull(filters)) {
            return filters;
        }
        else if (util_1.isObject(filters)) {
            const r = {};
            // tslint:disable-next-line: forin
            for (const k in filters) {
                let val = null;
                if (util_1.isArray(filters[k])) {
                    val = filters[k][0];
                }
                else {
                    val = filters[k];
                }
                r[k] = val;
            }
            return r;
        }
    }
    /**
     * Metodo para dar formato a los mensajes de salida.
     *
     * @param {DataRequest} Data Data que se pasa como resultado de la operacion
     * @param {*} response Respuesta
     * @param {number} errorCode Codigo del error al momento de la excepcion
     * @param {boolean} isForkError Indicador si el error proviene de una bifurcacion.
     * @param {ErrorMetadata} errorMeta Metadata del error de la bifurcacion.
     * @returns {ResponseMessage}
     * @memberof Base
     */
    formatResponse(Data, response, errorCode = null, isForkError = false, errorMeta) {
        // Variable para conocer si es un error o no
        let isError = false;
        // Validar si es un error
        if (!util_1.isNull(errorCode) && errorCode < 0) {
            isError = true;
        }
        // Objecto base de respuesta
        const resp = {
            data: Data.data,
            headers: Data.headers,
            metadata: Data.metadata,
            response: {
                data: {
                    response,
                },
                meta: {
                    id_transaction: Data.metadata.id_transaction,
                    status: isError ? 'ERROR' : 'SUCCESS',
                },
            },
            uuid: Data.uuid,
        };
        // Validar si es un error desde una bifurcacion.
        if (isForkError) {
            // Regresar todo
            return {
                error: errorMeta,
                fork: isForkError,
                response: resp,
            };
        }
        else {
            // Regresar todo
            return {
                error: {
                    errorCode,
                    userMessage: '',
                },
                fork: isForkError,
                response: resp,
            };
        }
    }
}
exports.default = Base;
